==> mongodb-6.0.25.gh.tar.gz: mongo-r6.0.25/src/mongo/util/periodic_runner.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/util/periodic_runner.h"

#include "mongo/util/assert_util.h"

namespace mongo {

PeriodicRunner::~PeriodicRunner() = default;

PeriodicJobAnchor::PeriodicJobAnchor(std::shared_ptr<Job> handle) : _handle{std::move(handle)} {}

PeriodicJobAnchor::~PeriodicJobAnchor() {
    if (!_handle) {
        return;
    }

    _handle->stop();
}

void PeriodicJobAnchor::start() {
    invariant(_handle);
    _handle->start();
}

void PeriodicJobAnchor::pause() {
    invariant(_handle);
    _handle->pause();
}

void PeriodicJobAnchor::resume() {
    invariant(_handle);
    _handle->resume();
}

void PeriodicJobAnchor::stop() {
    invariant(_handle);
    _handle->stop();
}

void PeriodicJobAnchor::setPeriod(Milliseconds ms) {
    invariant(_handle);
    _handle->setPeriod(ms);
}

Milliseconds PeriodicJobAnchor::getPeriod() {
    invariant(_handle);
    return _handle->getPeriod();
}

void PeriodicJobAnchor::detach() {
    _handle.reset();
}

bool PeriodicJobAnchor::isValid() const noexcept {
    return static_cast<bool>(_handle);
}

}  // namespace mongo

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/util/periodic_runner.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */


#include "mongo/util/periodic_runner.h"
#include "mongo/util/assert_util.h"

namespace mongo {

PeriodicRunner::~PeriodicRunner() = default;

PeriodicJobAnchor::PeriodicJobAnchor(std::shared_ptr<Job> handle) : _handle{std::move(handle)} {}

PeriodicJobAnchor::~PeriodicJobAnchor() {
    if (!_handle) {
        return;
    }

    _handle->stop();
}

void PeriodicJobAnchor::start() {
    invariant(_handle);
    _handle->start();
}

void PeriodicJobAnchor::pause() {
    invariant(_handle);
    _handle->pause();
}

void PeriodicJobAnchor::resume() {
    invariant(_handle);
    _handle->resume();
}

void PeriodicJobAnchor::stop() {
    invariant(_handle);
    _handle->stop();
}

void PeriodicJobAnchor::setPeriod(Milliseconds ms) {
    invariant(_handle);
    _handle->setPeriod(ms);
}

Milliseconds PeriodicJobAnchor::getPeriod() const {
    invariant(_handle);
    return _handle->getPeriod();
}

void PeriodicJobAnchor::detach() {
    _handle.reset();
}

bool PeriodicJobAnchor::isValid() const noexcept {
    return static_cast<bool>(_handle);
}

}  // namespace mongo
